# Security Policy

## Supported Versions

| Version | Supported          |
| ------- | ------------------ |
| 2.2.+   | :white_check_mark: |
| < 2.2   | :x:                |

## Reporting a Vulnerability

Hi! If you've found something off, we'd be more than happy if you would report it via security@speckle.systems. We will work together with you to correctly identify the cause and implement a fix. Thanks for helping make Speckle safer!
